@@ -1,7 +1,7 @@
 __author__ = ('Aitor Blanco (aitor.blancomiguez@unitn.it), '
              'Mireia Valles-Colomer (mireia.vallescolomer@unitn.it)')
-__version__ = '3.0.8'
-__date__ = '7 May 2021'
+__version__ = '3.0.10'
+__date__ = '15 Jun 2021'
 
 import os, time, sys
 import argparse as ap
@@ -22,7 +22,7 @@ Reads and parses the command line arguments of the script.
 :returns: the parsed arguments
 """
 def read_params():
-    p = ap.ArgumentParser(description="")
+    p = ap.ArgumentParser(description="", formatter_class=ap.ArgumentDefaultsHelpFormatter)
     p.add_argument('-t', '--tree', type=str, default=None,
                    help="The input tree file")
     p.add_argument('-m', '--metadata', type=str, default=None,
@@ -32,7 +32,7 @@ def read_params():
     p.add_argument('--save_dist', action='store_true',
                    help="[Optional] Save the PhyPhlAn pairwise distances file")
     p.add_argument('--threshold', type=float, default=DISTRIBUTION_THRESHOLD,
-                   help="[Optional] A custom distribution threshold value. Default: " + str(DISTRIBUTION_THRESHOLD))
+                   help="[Optional] A custom distribution threshold value")
     
     return p.parse_args()
 
@@ -48,6 +48,9 @@ def check_params(args):
     if not args.output_dir:
         error('-o (or --output_dir) must be specified', exit=True, 
             init_new_line=True)
+    elif not os.path.exists(args.output_dir):
+        error('The directory {} does not exist'.format(args.output_dir), exit=True, 
+            init_new_line=True)
     if not args.metadata:
         error('-m (or --metadata) must be specified', exit=True, 
             init_new_line=True)
